@@ -1,3 +1,9 @@
+## ----srr-tags, eval = FALSE, echo = FALSE-------------------------------------
+#  #' srr tags
+#  #'
+#  #'
+#  #' @srrstats {G1.5} two-sample test example in the associated paper
+
 ## ----message=FALSE------------------------------------------------------------
 library(sn)
 library(mvtnorm)
@@ -10,7 +16,7 @@ x_2 <- rmvnorm(n, mean = rep(0,d))
 y_2 <- rmsn(n=n, xi=0, Omega = diag(d), alpha=rep(skewness_y,d))
 
 ## -----------------------------------------------------------------------------
-h = 2
+h <- 2
 set.seed(2468)
 two_test <- kb.test(x=x_2, y=y_2, h=h)
 
